==> ecip-codegen-0.4.30.tgz: package/src/api/vue/genTemplate/gencodeTemplateApi.js <==
/**
 * @Author: huxiaolong
 * @File: gencode-template.js
 * @DATE: 2019-09-10
 * @TIME: 09:53
 */

import request from 'ecip-web/utils/request'

/* 获取模板列表 */
export const getTemplateList = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/list',
    method: 'get',
    params: params
  })
}

/* 根据Id删除模板 */
export const deleteTemplateById = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/delete',
    method: 'delete',
    params: params
  })
}

/* 获取类型节点树列表 */
export const getCategoryTreeList = (params) => {
  return request({
    url: 'api/v1/gencodeTemplateObjCategory/findTree',
    method: 'get',
    params: params
  })
}

/* 根据模板Id获取模板内容及模板文件 */
export const getTemplateById = (id) => {
  return request({
    url: `api/v1/template/gencodeTemplate/${id}`,
    method: 'get'
  })
}

/* 获取完整的节点树,包函子结点 */
export const getCategoryTreeWithChild = (params) => {
  return request({
    url: 'api/v1/gencode/templateObjCategory/findTreeWithChild',
    method: 'get',
    params: params
  })
}

/* 模板复制 */
export const copyTemplate = (id) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/copy',
    method: 'get',
    params: { id: id }
  })
}

/* 保存模板 */
export const saveTemplate = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate',
    method: 'post',
    data: params
  })
}

/* 修改模板 */
export const updateTemplate = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/update',
    method: 'put',
    data: params
  })
}

==> ecip-codegen-0.4.40.tgz: package/src/api/vue/genTemplate/gencodeTemplateApi.js <==
/**
 * @Author: huxiaolong
 * @File: gencode-template.js
 * @DATE: 2019-09-10
 * @TIME: 09:53
 */

import request from 'ecip-web/utils/request'

/* 获取表格列表 */
export const getTemplateData = (params, data) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/data',
    method: 'post',
    data: data || {},
    params: params
  })
}

/* 获取模板列表 */
export const getTemplateList = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/list',
    method: 'get',
    params: params
  })
}

/* 根据Id删除模板 */
export const deleteTemplateById = (data) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/delete',
    method: 'delete',
    data: data || []
  })
}

/* 获取类型节点树列表 */
export const getCategoryTreeList = (params) => {
  return request({
    url: 'api/v1/gencodeTemplateObjCategory/findTree',
    method: 'get',
    params: params
  })
}

/* 根据模板Id获取模板内容及模板文件 */
export const getTemplateById = (id) => {
  return request({
    url: `api/v1/template/gencodeTemplate/${id}`,
    method: 'get'
  })
}

/* 获取完整的节点树,包函子结点 */
export const getCategoryTreeWithChild = (params) => {
  return request({
    url: 'api/v1/gencode/templateObjCategory/findTreeWithChild',
    method: 'get',
    params: params
  })
}

/* 模板复制 */
export const copyTemplate = (id) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/copy',
    method: 'get',
    params: { id: id }
  })
}

/* 保存模板 */
export const saveTemplate = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate',
    method: 'post',
    data: params
  })
}

/* 修改模板 */
export const updateTemplate = (params) => {
  return request({
    url: 'api/v1/template/gencodeTemplate/update',
    method: 'put',
    data: params
  })
}
